==> haskell-x509-1.7.7-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-EG44MlHz60DKggFVaTpGiE
key:                  x509-1.7.7-EG44MlHz60DKggFVaTpGiE
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  2a76d33e30e24f661382f8023cfd3364
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-EG44MlHz60DKggFVaTpGiE
depends:
    asn1-encoding-0.9.6-Ad3LLL3CDtvIC0gzmiepHT
    asn1-parse-0.9.5-HxZg8Acy978ACybULyTzJk
    asn1-types-0.3.4-3loQto5LRBpFKUk7N5Cpk7 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-CuyVAaLmJNF5moPTPURptl
    hourglass-0.2.12-CntI9UQk4VpJlgia8F0Px7
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-APG2WCMWsj6Hi2gRusfHzZ transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.7-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-FRRDlzOEqqK3emzMHgu31M
key:                  x509-1.7.7-FRRDlzOEqqK3emzMHgu31M
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  9f0001c2ea2873bafce04a7b5cbaa23d
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-FRRDlzOEqqK3emzMHgu31M
depends:
    asn1-encoding-0.9.6-KI5Zdg4pdVPC8vcGnlwtjG
    asn1-parse-0.9.5-AGDimBF1kAkRtOMImRxo1
    asn1-types-0.3.4-Gla04HcvDO18FBY9rV7iXP base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-J7ZTOwzJUyuA1lPez0TsXy
    hourglass-0.2.12-7KFeZE6j4iLAuc8KMyy8fY
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-ETuKErN1kikDhjtvNWae6G transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
